@@ -4,7 +4,9 @@ use 5.008004;
 use strict;
 use warnings;
 
-use LWP::Simple;
+use LWP::UserAgent;
+use HTTP::Request;
+use Location::GeoTool;
 
 require Exporter;
 
@@ -27,13 +29,13 @@ our @EXPORT = qw(
 	lookup
 );
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 # Preloaded methods go here.
 
 my $entry_point = 'http://api.map.yahoo.co.jp/MapsService/V1/search';
 
-use Data::Dumper;
+my $ua = undef;
 
 sub lookup {
 	my $address = shift;
@@ -41,6 +43,10 @@ sub lookup {
 
 	$address or return undef;
 
+	$ua or $ua = LWP::UserAgent->new(agent => __PACKAGE__ . "/$VERSION");
+
+	my $datum = $opts->{datum} || 'wgs84';
+
 	defined $opts->{num} or $opts->{num} = 10;
 	defined $opts->{prop} or $opts->{prop} = 'widget';
 	$address =~ s/([\W])/ sprintf "%%%02X", ord($1) /ge;
@@ -56,25 +62,36 @@ sub lookup {
 	
 	my $q = join "&", ( map { "$_=" . $params->{$_} } (keys %$params) );
 	my $url = "$entry_point?$q";
-	my $response = get( $url );
+	my $response = $ua->get( $url );
 
 	$response or return undef;
+	my $content = $response->content;
 	
 	my @items = ();
-	@_ = split m|<item>|, $response;
+	@_ = split m|<item>|, $content;
 	scalar @_ == 0 and return undef;
 
-	while ( $response =~ m|<item>(.+?)</item>|sg ) {
+	while ( $content =~ m|<item>(.+?)</item>|sg ) {
 		my $item_content = $1;
 
 		my $result = {};
 		while ( $item_content =~ m|<(\w+)>(.+?)</\1>|g ) {
 			$result->{$1} = $2;
 		}
+		if ( $datum !~ /^tokyo$/i ) {
+			my $tokyo = Location::GeoTool->create_coord(
+				$result->{latitude}, $result->{longitude}, 'tokyo', 'degree');
+			my $wgs = $tokyo->datum_wgs84;
+			$wgs->format_degree;
+			$result->{latitude}  = $wgs->lat;
+			$result->{longitude} = $wgs->long;
+		}
 		push @items, $result;
 	}
 
+
 	return {
+		datum => $datum,
 		latitude => $items[0]->{latitude},
 		longitude => $items[0]->{longitude},
 		hits => scalar @items,
@@ -93,21 +110,16 @@ Geo::Coder::YahooJapan - a simple wrapper for Yahoo Japan Geocoder API
 =head1 SYNOPSIS
 
   use Geo::Coder::YahooJapan;
-  my $r = lookup("$B?@F`@n8)@n:j;TCf866h0fED(B2-21-6");
-  my ($lat, $lng) = ( $r->{latitude}, $r->{longitude} ); # coordinate in TOKYO.
+  $r = lookup( $address_in_japanese_characters );
+  my ($lat, $lng) = ( $r->{latitude}, $r->{longitude} ); # coordinate in WGS87.
 
-  use Location::GeoTool;
-  my $tokyo = Location::GeoTool->create_coord($lat, $lng, 'tokyo', 'degree');
-  my $wgs = $tokyo->datum_wgs84;
-  my $wgs->format_degree;
-  
-  # coordinate in WGS87.
-  ($lat, $lng) = ($wgs->lat, $wgs->long);
+  # if you want to get result in TOKYO datum, specify it in option.
+  $r = lookup( $address_in_japanese_characters, { datum => 'tokyo' } );
 
   # if address is ambiguous and the server returns multiple items
-  my $r = lookup("$BEl5~ET=BC+6hEl(B");
+  $r = lookup( $address_in_japanese_characters );
   # $r->{latitude} and $r->{longitude} contains coordinate of first item.
-  my ($lat, $lng) = ( $r->{latitude}, $r->{longitude} );
+  ($lat, $lng) = ( $r->{latitude}, $r->{longitude} );
 
   # $r->{hits} has the number of candidates.
   if ( $r->{hits} > 1 ) {
@@ -123,8 +135,7 @@ Geo::Coder::YahooJapan - a simple wrapper for Yahoo Japan Geocoder API
 Geo::Coder::YahooJapan is a wrapper for Yahoo Japan Geocoder API that is used by the
 official Yahoo Japan's local search widget
 L<http://widgets.yahoo.co.jp/gallery/detail.html?wid=10> .
-The API returns coordinates in TOKYO datum. if you need the coordinates in WGS84,
-you need to convert them with Location::GeoTool etc.
+This module converts the coordinate into WGS84 from TOKYO datum which is returned by API server.
 
 =head3 lookup(address, opts)
 
@@ -134,14 +145,13 @@ These candidatse are found in $response->{items}. You can determine geocoding re
 
 You can specify the address in UTF8, SHIFT_JIS, EUC_JP. But the API server does not understand ISO-2022-JP, so you need convert into other character set if your address is written in ISO-2022-JP.
 In $opts->{num}, you can specify the number of candidates you want to receive when multiple items are found. Default value is 10.
+If you want to get results in other datum, not in WGS84, set the datum name in $opts->{datum}. the value is passed to Location::GeoTool and it converts them properly.
 
 =head1 DEPENDENCIES
 
-using L<LWP::Simple> to make a request to the API server.
-
-=head1 SEE ALSO
-
-L<Location::GeoTool> can convert coordination systems.
+L<HTTP::Request>
+L<LWP::UserAgent>
+L<Location::GeoTool>
 
 =head1 AUTHOR
 
